//+------------------------------------------------------------------+
//|                                               Andre EA v1.15.mq4 |
//|                                       Copyright  2008 Tom Balfe |
//|                   http://www.forex-tsd.com/members/nittany1.html |
//|                                                                  |
//| Moving Average based Expert Advisor. I added stochastics, ADX    |
//| directional index to try to help filter out bad trades. This     |
//| version adds separate trade rules for a strong trend.            |
//+------------------------------------------------------------------+

#property copyright "Copyright  2008 Tom Balfe"
#property link      "http://www.forex-tsd.com/members/nittany1.html"

//+------------------------------------------------------------------+
//| USER ADJUSTABLE STUFF                                            |
//+------------------------------------------------------------------+

extern  string  TopOfSetting          = "=== Andre v1.15 EA ===";
extern  int     MagicNumber           = 112722;
extern  int     WaitMinutes           = 2; 

extern  string  Order_Settings        = "=== Order Settings ===";
extern  double  StaticLots            = 0.1;
extern  int     Slippage              = 5;
extern  int     TP                    = 60;
extern  int     SL                    = 30;

extern  string  MM_Settings           = "=== Money Management ===";
extern  bool    UseMM                 = false;
extern  int     PercentAtRisk         = 3;

extern  string  ADX_Settings          = "=== ADX ===";
extern  int     ADXTrend              = 20;
extern  int     ADXStrongTrend        = 30;

//+------------------------------------------------------------------+
//| DON'T CHANGE BELOW HERE                                          |
//+------------------------------------------------------------------+
//| Program initializes and deinitializes here.                      |
//+------------------------------------------------------------------+
string        EAComment   = "Andre v1.15 EA";
int           OpenOrders  = 1;
datetime      PreviousBar;

int init()
  {

  return(0);
  }

int deinit()
  {
    if (TotalOpenOrders() > 0)
    {
    CloseAll();
    } 
   
  return(0);
  }
  
//+------------------------------------------------------------------+
//| MAIN LOOP                                                        |
//+------------------------------------------------------------------+
//| Program spends most of its life going through this main loop.    |
//+------------------------------------------------------------------+
int start()
  {
  //--- Moving Average
  double shortMA      = iMA(NULL,0,5,0,MODE_EMA,PRICE_CLOSE,0);
  double longMA       = iMA(NULL,0,9,0,MODE_LWMA,PRICE_CLOSE,0);
  
  //--- Stochastics
  double sMain        = iStochastic(NULL,0,8,3,3,MODE_SMA,0,MODE_MAIN,0);
  double sSignal      = iStochastic(NULL,0,8,3,3,MODE_SMA,0,MODE_SIGNAL,0);
  
  //--- Directional Index
  double adx          = iADX(NULL,0,14,PRICE_CLOSE,0,0); // ADX
  double di_p         = iADX(NULL,0,14,PRICE_CLOSE,1,0); // DI+ 
  double di_m         = iADX(NULL,0,14,PRICE_CLOSE,2,0); // DI-   
   
  //------------------- order management -------------------//
  if (ElapsedTimeCheck(WaitMinutes) == true) {
  
    //---------------- check indicators and look for a CLOSE ---//
    if (TotalOpenOrders() == OpenOrders)
    {
      if (adx<ADXStrongTrend) { // if adx is less than strong trend
        if (OrderType() == OP_BUY) {
          if ((sSignal > sMain)||(longMA > shortMA)){ CloseAll(); }
        }
        if (OrderType() == OP_SELL) {
          if ((sMain > sSignal)&&(shortMA > longMA)){ CloseAll(); }
        }
      } // end of if adx is less than strong trend
      
      if (adx>=ADXStrongTrend) { // if adx is more than strong trend
        if (OrderType() == OP_BUY) {
          if (sMain<80) { CloseAll(); }
        }
        if (OrderType() == OP_SELL) {
          if (sMain>20) { CloseAll(); }
        }
      } // end of if adx is more than strong trend    
    } // end of if we have orders
    
    //---------------- check indicators and look for a ORDER ENTRY ---//
    if (TotalOpenOrders() < OpenOrders)
    {
      if (adx<ADXStrongTrend) { // if adx is more than trend but less than strong trend
        if ((sMain>sSignal)&&(shortMA>longMA)&&(di_p>di_m)&&(adx>ADXTrend)) // BUY
          {
          OrderSend(Symbol(),OP_BUY,LotSize(),Ask,Slippage,Ask-SL*Point,Ask+TP*Point,EAComment,MagicNumber,0,Lime);  
          }  
        if ((sSignal>sMain)&&(longMA > shortMA)&&(di_m > di_p)&&(adx>ADXTrend)) // SELL
          {
          OrderSend(Symbol(),OP_SELL,LotSize(),Bid,Slippage,Bid+SL*Point,Ask-TP*Point,EAComment,MagicNumber,0,Red);
          }
      }
      
      if (adx>=ADXStrongTrend) { // if adx is more than or equal to strong trend
        if ((shortMA>longMA)&&(di_p>di_m)) // BUY
          {
          OrderSend(Symbol(),OP_BUY,LotSize(),Ask,Slippage,Ask-SL*Point,Ask+TP*Point,EAComment,MagicNumber,0,Lime);  
          } 
        if ((longMA<shortMA)&&(di_m>di_p)) // SELL
          {
          OrderSend(Symbol(),OP_SELL,LotSize(),Bid,Slippage,Bid+SL*Point,Ask-TP*Point,EAComment,MagicNumber,0,Red);
          }
      }    
    } // end of if no orders exist
  } // end of if elapsed time has passed
  
  return(0);
  } // end of main loop

//+------------------------------------------------------------------+
//| COMMON FUNCTIONS                                                 |
//+------------------------------------------------------------------+
//| The expert will call these from the main loop.                   |
//+------------------------------------------------------------------+

//+-----------------------------------------------------+
//|           trade interval                            |
//+-----------------------------------------------------+
bool ElapsedTimeCheck(int mins)
{
  static datetime OldTime;
 
  if (OldTime == 0)
    OldTime = TimeCurrent() + mins * 60; // initialised once...

  if (TimeCurrent() >= OldTime) 
  {
    OldTime = TimeCurrent() + mins * 60;
    bool cond = true;
  }
  else cond = false;
 
 return(cond);
}

//+-----------------------------------------------------+
//|           calculate lot size                        |
//+-----------------------------------------------------+
double LotSize()
{
  if (UseMM == true) 
    { double Lots = MathCeil(AccountFreeMargin() *  PercentAtRisk / 1000) / 100; }
  
  else { Lots = StaticLots; }
  
  return(Lots);  
}

//+-----------------------------------------------------+
//|           close all                                 |
//+-----------------------------------------------------+
//| Finds any open orders & closes them                 |
//+-----------------------------------------------------+
void CloseAll()
{
  int total = OrdersTotal();
  for(int i=total-1;i>=0;i--)
  {
    OrderSelect(i, SELECT_BY_POS);
    int type = OrderType();
    
    if (OrderSymbol()==Symbol() && (OrderMagicNumber() == MagicNumber))  
    {
      //-- Close open BUYs
      if (type == OP_BUY) OrderClose(OrderTicket(),OrderLots(),MarketInfo(OrderSymbol(),MODE_BID),Slippage,CornflowerBlue);
      //-- Close open SELLS
      if (type == OP_SELL) OrderClose(OrderTicket(),OrderLots(),MarketInfo(OrderSymbol(),MODE_ASK),Slippage,CornflowerBlue);
    }
  }
  return;
}

//+-----------------------------------------------------+
//|           calculate open orders                     |
//+-----------------------------------------------------+
int TotalOpenOrders()
{
  int j = 0;
  j=OrdersTotal();
  int TotalOpenOrders = 0;
   
  if(j==0) { return (0); }
  
  else
  {
    for(;j>=0;j--)
      {
      RefreshRates();
      OrderSelect(j,SELECT_BY_POS);
      if(OrderMagicNumber()==MagicNumber)
      {
        TotalOpenOrders++;
      }
    }
  }
  return(TotalOpenOrders);
}

